# mistymountain

[![Azure Status](https://dev.azure.com/timgates42/timgates42/_apis/build/status/timgates42.mistymountain?branchName=master)](https://dev.azure.com/timgates42/timgates42/_build/latest?definitionId=timgates42&branchName=master)
[![Travis Status](https://travis-ci.org/timgates42/mistymountain.svg?branch=master)](https://travis-ci.org/timgates42/mistymountain)
[![Appveyor Status](https://ci.appveyor.com/api/projects/status/github/appveyor_user_goes_here/mistymountain/branch/master?svg=true)](https://ci.appveyor.com/project/appveyor_user_goes_here/mistymountain)
[![PyPI version](https://img.shields.io/pypi/v/mistymountain.svg)](https://pypi.org/project/mistymountain)
[![Python Versions](https://img.shields.io/pypi/pyversions/mistymountain.svg)](https://pypi.org/project/mistymountain)
[![PyPI downloads per month](https://img.shields.io/pypi/dm/mistymountain.svg)](https://pypi.org/project/mistymountain)
[![Documentation Status](https://readthedocs.org/projects/mistymountain/badge/?version=latest)](https://mistymountain.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/timgates42/mistymountain/badge.svg)](https://coveralls.io/github/timgates42/mistymountain/)
[![Black](https://camo.githubusercontent.com/28a51fe3a2c05048d8ca8ecd039d6b1619037326/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667)](https://github.com/psf/black)

Cloud Based Helper Library

More details can be found in the
[Online Documentation.](https://mistymountain.readthedocs.io/en/latest/)

# Installation

You can install mistymountain for
[Python](https://www.python.org/) via
[pip](https://pypi.org/project/pip/)
from [PyPI](https://pypi.org/).

```
$ pip install mistymountain
```





## Download from PyPI.org

https://pypi.org/project/mistymountain/



# Contributing

Contributions are very welcome, consider using the
[file an issue](https://github.com/timgates42/mistymountain/issues)
to discuss the work before beginning, but if you already have a Pull Request
ready then this is no problem, please submit it and it will be very gratefully
considered. The [Contribution Guidelines](CONTRIBUTING.md)
outlines the mistymountain commitment to ensuring all
contributions receive appropriate recognition.

# Issues

If you encounter any problems, please
[file an issue](https://github.com/timgates42/mistymountain/issues)
along with a detailed description.

# Additional Documentation:

* [Online Documentation](https://mistymountain.readthedocs.io/en/latest/)
* [News](NEWS.rst).
* [Template Updates](COOKIECUTTER_UPDATES.md).
* [Code of Conduct](CODE_OF_CONDUCT.md).
* [Contribution Guidelines](CONTRIBUTING.md).
